@@ -303,6 +303,48 @@ define ([
                 entries: ['selectActivityAction', 'createSingleIntSave']
             }
         }); // createSingleInt
+
+        target.push('createLastPlusOffset', {
+            // before doing any calculations, look up:
+            // - employee's schedule
+            // - schedule intervals on date
+            // - existing intervals on date
+            // timerange start will be:
+            // - end of last existing interval, if there are existing intervals
+            // - start of first schedule interval, if there are schedule intervals
+            // - 00:00 otherwise
+            // timerange end will be timerange start plus offset
+            'name': 'createLastPlusOffset',
+            'type': 'dform',
+            'menuText': "Last plus offset",
+            'title': "Create interval \"last plus offset\"",
+            'aclProfile': 'active',
+            'entriesRead': [entries.iNdate, entries.iNact, entries.iNdesc,
+                            entries.iNschedintvls, entries.iNlastexistintvl, entries.iNlastplusoffset,],
+            'miniMenu': {
+                entries: ['createLastPlusOffsetSave'],
+            }
+        }); // createLastPlusOffset
+
+        target.push('createNextScheduled', {
+            // before doing any calculations, look up/calculate:
+            // - employee's schedule
+            // - existing intervals on date
+            // - schedule intervals on date
+            // timerange will be:
+            // - first schedule interval that does not conflict/overlap with an existing interval
+            'name': 'createNextScheduled',
+            'type': 'dform',
+            'menuText': "Next scheduled",
+            'title': "Create interval \"next scheduled\"",
+            'aclProfile': 'active',
+            'entriesRead': [entries.iNdate, entries.iNact, entries.iNdesc,
+                            entries.iNschedintvls, entries.iNlastexistintvl, entries.iNnextscheduled,],
+            'miniMenu': {
+                entries: ['createNextScheduledSave'],
+            }
+        }); // createNextScheduled
+
         target.push('createMultipleInt', {
             'name': 'createMultipleInt',
             'type': 'dform',
@@ -314,6 +356,7 @@ define ([
                 entries: ['fillUpAction']
             }
         }); // createMultipleInt
+
         target.push('displaySingleInt', {
             'name': 'displaySingleInt',
             'type': 'dform',
